@@ -519,6 +519,11 @@ class Get_App_Appinfo(Qimai_Diy_Var):
         self.developer_name = self.appinfo['appInfo']['publisher_seller']
         return self.developer_name
 
+    def get_purchases_num(self):
+        self.get_appinfo()
+        self.purchases_num = self.appinfo['appInfo']['purchases_num']
+        return self.purchases_num
+
 # 获取榜单相关数据；
 class Get_App_Rank(Qimai_Diy_Var):
     """
